@@ -2,7 +2,7 @@
 from __future__ import annotations
 
 from dataclasses import dataclass
-from datetime import datetime
+from datetime import date, datetime
 from enum import Enum
 from re import search
 from typing import Any
@@ -10,6 +10,7 @@ from typing import Any
 from ..const import ATTR_DATA
 from .const import (
     CONVERT_TO_BOOL,
+    CONVERT_TO_DATE,
     CONVERT_TO_DATETIME,
     CONVERT_TO_ENUM,
     CONVERT_TO_FLOAT,
@@ -18,7 +19,9 @@ from .const import (
 )
 
 
-def get_datetime(_input: datetime | str | None) -> datetime | str | int | None:
+def get_datetime(
+    _input: datetime | str | None, utc: bool = False
+) -> datetime | str | int | None:
     """Convert input to datetime object."""
     if isinstance(_input, str):
         if _input.isnumeric():
@@ -26,11 +29,20 @@ def get_datetime(_input: datetime | str | None) -> datetime | str | int | None:
         if res := search(r"(\d+-\d{2}-\d{2})T?(\d{2}:\d{2}:\d{2})?\.*((.*)Z)?", _input):
             if res.group(2):
                 _input = f"{res.group(1)}{res.group(2)}{f'{res.group(4)}000000'[:6]}"
+                if utc:
+                    return datetime.strptime(f"{_input}+00:00", "%Y-%m-%d%H:%M:%S%f%z")
                 return datetime.strptime(_input, "%Y-%m-%d%H:%M:%S%f")
             return datetime.strptime(_input, "%Y-%m-%d")
     return _input
 
 
+def get_date(_input: datetime | str | None) -> date | str | int | None:
+    """Convert input to date object."""
+    if (result := get_datetime(_input)) and isinstance(result, datetime):
+        return result.date()
+    return result
+
+
 def get_enum_value(val: str) -> str | Enum:
     """Convert input to the correct enum."""
     for protocol in ProtocolType:
@@ -85,7 +97,12 @@ class BaseModel:
                 if key == ATTR_DATA:
                     value = generate_data(value, datatype)
                 elif key in CONVERT_TO_DATETIME:
-                    value = get_datetime(value)
+                    if key == "airDateUtc":
+                        value = get_datetime(value, utc=True)
+                    else:
+                        value = get_datetime(value)
+                elif key in CONVERT_TO_DATE:
+                    value = get_date(value)
                 elif key in CONVERT_TO_ENUM:
                     value = get_enum_value(value)
                 elif key in CONVERT_TO_FLOAT and value is not None:
