@@ -77,7 +77,7 @@ class RequestClient:  # pylint: disable=too-many-public-methods
     __name__ = ""
     _close_session = False
 
-    def __init__(  # pylint: disable=too-many-arguments
+    def __init__(  # pylint: disable=too-many-arguments, too-many-locals
         self,
         port: int,
         request_timeout: float,
@@ -119,6 +119,12 @@ class RequestClient:  # pylint: disable=too-many-public-methods
             self._close_session = True
 
         self._host = host_configuration
+        if self._host.url:
+            regex = r"(https?:\/\/[a-z|\d|\.]*[^:])([\/^:\d]*)(.*)"
+            if (res := search(regex, self._host.url)) and not res.group(2):
+                self._host.url = f"{res.group(1).rstrip('/')}:{port}/{res.group(3)}"
+            self._host.url = self._host.url.rstrip("/")
+        self._headers = HEADERS | {"X-Api-Key": self._host.api_token or api_token}
         self._session = session
         self._request_timeout = request_timeout
         self._raw_response = raw_response
@@ -148,7 +154,7 @@ class RequestClient:  # pylint: disable=too-many-public-methods
                 url=url,
                 params=params,
                 json=toraw(data),
-                headers=HEADERS,
+                headers=self._headers,
                 timeout=ClientTimeout(self._request_timeout),
                 ssl=self._host.verify_ssl,
             )
@@ -241,15 +247,6 @@ class RequestClient:  # pylint: disable=too-many-public-methods
         """Get information about diskspace."""
         return await self._async_request("diskspace", datatype=Diskspace)
 
-    async def async_get_root_folders(
-        self, folderid: int | None = None
-    ) -> RootFolder | list[RootFolder]:
-        """Get information about root folders."""
-        return await self._async_request(
-            f"rootfolder{'' if folderid is None else f'/{folderid}'}",
-            datatype=RootFolder,
-        )
-
     async def async_delete_root_folder(self, folderid: int) -> None:
         """Delete information about root folders."""
         return await self._async_request(
